/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.base;

import java.util.ArrayList;
import java.util.List;

import org.conqat.lib.commons.collections.CollectionUtils;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.interfaces.IPrototypeProvider;
import org.fortiss.tooling.kernel.services.IPrototypeService.Prototype;

/**
 * Base implementation for {@link IPrototypeProvider}s.
 * 
 * @author hoelzlf
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: A626C3CA9399C902B150A350464FA8FA
 */
public abstract class PrototypeProviderBase implements IPrototypeProvider {

	/** Stores the registered prototypes. */
	private final List<Prototype> prototypes = new ArrayList<Prototype>();

	/** Constructor. */
	public PrototypeProviderBase() {
		registerPrototypes();
	}

	/** Registers all prototypes. Sub-classes must override. */
	protected abstract void registerPrototypes();

	/** Registers the given {@link EObject} with the given name. */
	protected final void registerPrototype(String name, EObject prototype) {
		prototypes.add(new Prototype(name, prototype));
	}

	/** {@inheritDoc} */
	@Override
	public List<Prototype> getPrototypes() {
		return CollectionUtils.asUnmodifiable(prototypes);
	}
}
