/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.internal;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.interfaces.ITopLevelElementContext;
import org.fortiss.tooling.kernel.services.ICommandStackService;
import org.fortiss.tooling.kernel.services.IPersistencyService;

/**
 * This class implements the {@link ICommandStackService} interface. This class
 * mainly delegates its calls to the {@link IPersistencyService}.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: EE8051A4DB3F027875C4AD6C23B346C5
 */
public class CommandStackService implements ICommandStackService {
	/** {@inheritDoc} */
	@Override
	public void runAsCommand(EObject target, Runnable runner) {
		ITopLevelElementContext context = IPersistencyService.INSTANCE
				.getTopLevelElementContextFor(target);
		if (context != null) {
			context.runAsCommand(runner);
		}
	}

	/** {@inheritDoc} */
	@Override
	public boolean canUndo(EObject target) {
		ITopLevelElementContext context = IPersistencyService.INSTANCE
				.getTopLevelElementContextFor(target);
		return context != null && context.canUndo();
	}

	/** {@inheritDoc} */
	@Override
	public boolean canRedo(EObject target) {
		ITopLevelElementContext context = IPersistencyService.INSTANCE
				.getTopLevelElementContextFor(target);
		return context != null && context.canRedo();
	}

	/** {@inheritDoc} */
	@Override
	public void undo(EObject target) {
		IPersistencyService.INSTANCE.getTopLevelElementContextFor(target)
				.undo();

	}

	/** {@inheritDoc} */
	@Override
	public void redo(EObject target) {
		IPersistencyService.INSTANCE.getTopLevelElementContextFor(target)
				.redo();
	}
}
