/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.services;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.Saveable;
import org.eclipse.ui.part.ViewPart;
import org.fortiss.tooling.kernel.internal.NavigatorService;

/**
 * The navigator service provides model navigation support.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: 9B9DAAC0BFE14D2AE78C879E96598ED5
 */
public interface INavigatorService {

	/** Returns the singleton instance of the service. */
	public static final INavigatorService INSTANCE = new NavigatorService();

	/** Returns view id of the navigator view. */
	public static final String NAVIGATOR_VIEW = "org.fortiss.tooling.kernel.model.navigator";

	/**
	 * Returns the navigator view part. May return <code>null</code> if
	 * navigator has not yet been created or has already been disposed.
	 */
	ViewPart getNavigatorView();

	/** Returns the current naviaator selection. */
	ISelection getCurrentSelection();

	/** Returns the saveables. */
	Saveable[] getSaveables();

	/** Returns the saveables of the current selection. */
	Saveable[] getActiveSaveables();

	/** Reveals the given model element. */
	void revealModelElement(EObject modelElement);
}
